/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.civicinfo.model;

import com.google.api.client.json.GenericJson;

/**
 * Describes information about a regional election administrative area.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Civic Information API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class AdministrationRegion extends GenericJson {

  /**
   * The election administration body for this area.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private AdministrativeBody electionAdministrationBody;

  /**
   * An ID for this object. IDs may change in future requests and should not be cached. Access to
   * this field requires special access that can be requested from the Request more link on the
   * Quotas page.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The city or county that provides election information for this voter. This object can have the
   * same elements as state.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("local_jurisdiction")
  private AdministrationRegion localJurisdiction;

  /**
   * The name of the jurisdiction.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * A list of sources for this area. If multiple sources are listed the data has been aggregated
   * from those sources.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Source> sources;

  static {
    // hack to force ProGuard to consider Source used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Source.class);
  }

  /**
   * The election administration body for this area.
   * The value returned may be {@code null}.
   */
  public AdministrativeBody getElectionAdministrationBody() {
    return electionAdministrationBody;
  }

  /**
   * The election administration body for this area.
   * The value set may be {@code null}.
   */
  public AdministrationRegion setElectionAdministrationBody(AdministrativeBody electionAdministrationBody) {
    this.electionAdministrationBody = electionAdministrationBody;
    return this;
  }

  /**
   * An ID for this object. IDs may change in future requests and should not be cached. Access to
   * this field requires special access that can be requested from the Request more link on the
   * Quotas page.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * An ID for this object. IDs may change in future requests and should not be cached. Access to
   * this field requires special access that can be requested from the Request more link on the
   * Quotas page.
   * The value set may be {@code null}.
   */
  public AdministrationRegion setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The city or county that provides election information for this voter. This object can have the
   * same elements as state.
   * The value returned may be {@code null}.
   */
  public AdministrationRegion getLocalJurisdiction() {
    return localJurisdiction;
  }

  /**
   * The city or county that provides election information for this voter. This object can have the
   * same elements as state.
   * The value set may be {@code null}.
   */
  public AdministrationRegion setLocalJurisdiction(AdministrationRegion localJurisdiction) {
    this.localJurisdiction = localJurisdiction;
    return this;
  }

  /**
   * The name of the jurisdiction.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * The name of the jurisdiction.
   * The value set may be {@code null}.
   */
  public AdministrationRegion setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * A list of sources for this area. If multiple sources are listed the data has been aggregated
   * from those sources.
   * The value returned may be {@code null}.
   */
  public java.util.List<Source> getSources() {
    return sources;
  }

  /**
   * A list of sources for this area. If multiple sources are listed the data has been aggregated
   * from those sources.
   * The value set may be {@code null}.
   */
  public AdministrationRegion setSources(java.util.List<Source> sources) {
    this.sources = sources;
    return this;
  }

}
