/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.civicinfo.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * Information about a candidate running for elected office.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Civic Information API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Candidate extends GenericJson {

  /**
   * The URL for the candidate's campaign web site.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String candidateUrl;

  /**
   * A list of known (social) media channels for this candidate.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Channel> channels;

  static {
    // hack to force ProGuard to consider Channel used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Channel.class);
  }

  /**
   * The email address for the candidate's campaign.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String email;

  /**
   * The candidate's name.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * The order the candidate appears on the ballot for this contest.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long orderOnBallot;

  /**
   * The full name of the party the candidate is a member of.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String party;

  /**
   * The voice phone number for the candidate's campaign office.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String phone;

  /**
   * A URL for a photo of the candidate.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String photoUrl;

  /**
   * The URL for the candidate's campaign web site.
   * The value returned may be {@code null}.
   */
  public String getCandidateUrl() {
    return candidateUrl;
  }

  /**
   * The URL for the candidate's campaign web site.
   * The value set may be {@code null}.
   */
  public Candidate setCandidateUrl(String candidateUrl) {
    this.candidateUrl = candidateUrl;
    return this;
  }

  /**
   * A list of known (social) media channels for this candidate.
   * The value returned may be {@code null}.
   */
  public java.util.List<Channel> getChannels() {
    return channels;
  }

  /**
   * A list of known (social) media channels for this candidate.
   * The value set may be {@code null}.
   */
  public Candidate setChannels(java.util.List<Channel> channels) {
    this.channels = channels;
    return this;
  }

  /**
   * The email address for the candidate's campaign.
   * The value returned may be {@code null}.
   */
  public String getEmail() {
    return email;
  }

  /**
   * The email address for the candidate's campaign.
   * The value set may be {@code null}.
   */
  public Candidate setEmail(String email) {
    this.email = email;
    return this;
  }

  /**
   * The candidate's name.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * The candidate's name.
   * The value set may be {@code null}.
   */
  public Candidate setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * The order the candidate appears on the ballot for this contest.
   * The value returned may be {@code null}.
   */
  public Long getOrderOnBallot() {
    return orderOnBallot;
  }

  /**
   * The order the candidate appears on the ballot for this contest.
   * The value set may be {@code null}.
   */
  public Candidate setOrderOnBallot(Long orderOnBallot) {
    this.orderOnBallot = orderOnBallot;
    return this;
  }

  /**
   * The full name of the party the candidate is a member of.
   * The value returned may be {@code null}.
   */
  public String getParty() {
    return party;
  }

  /**
   * The full name of the party the candidate is a member of.
   * The value set may be {@code null}.
   */
  public Candidate setParty(String party) {
    this.party = party;
    return this;
  }

  /**
   * The voice phone number for the candidate's campaign office.
   * The value returned may be {@code null}.
   */
  public String getPhone() {
    return phone;
  }

  /**
   * The voice phone number for the candidate's campaign office.
   * The value set may be {@code null}.
   */
  public Candidate setPhone(String phone) {
    this.phone = phone;
    return this;
  }

  /**
   * A URL for a photo of the candidate.
   * The value returned may be {@code null}.
   */
  public String getPhotoUrl() {
    return photoUrl;
  }

  /**
   * A URL for a photo of the candidate.
   * The value set may be {@code null}.
   */
  public Candidate setPhotoUrl(String photoUrl) {
    this.photoUrl = photoUrl;
    return this;
  }

}
