/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.civicinfo.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * Information about a contest that appears on a voter's ballot.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Civic Information API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Contest extends GenericJson {

  /**
   * A number specifying the position of this contest on the voter's ballot.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long ballotPlacement;

  /**
   * The candidate choices for this contest.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Candidate> candidates;

  static {
    // hack to force ProGuard to consider Candidate used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Candidate.class);
  }

  /**
   * Information about the electoral district that this contest is in.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ElectoralDistrict district;

  /**
   * A description of any additional eligibility requirements for voting in this contest.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String electorateSpecifications;

  /**
   * An ID for this object. IDs may change in future requests and should not be cached. Access to
   * this field requires special access that can be requested from the Request more link on the
   * Quotas page.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The level of office for this contest. One of: federal, state, county, city, other
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String level;

  /**
   * The number of candidates that will be elected to office in this contest.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long numberElected;

  /**
   * The number of candidates that a voter may vote for in this contest.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long numberVotingFor;

  /**
   * The name of the office for this contest.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String office;

  /**
   * If this is a partisan election, the name of the party it is for.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String primaryParty;

  /**
   * A brief description of the referendum. This field is only populated for contests of type
   * 'Referendum'.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String referendumSubtitle;

  /**
   * The title of the referendum. (e.g. 'Proposition 42') This field is only populated for contests
   * of type 'Referendum'.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String referendumTitle;

  /**
   * A link the referendum. This field is only populated for contests of type 'Referendum'.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String referendumUrl;

  /**
   * A list of sources for this contest. If multiple sources are listed, the data has been
   * aggregated from those sources.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Source> sources;

  static {
    // hack to force ProGuard to consider Source used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Source.class);
  }

  /**
   * "Yes" or "No" depending on whether this a contest being held outside the normal election cycle.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String special;

  /**
   * The type of contest. Usually this will be 'General', 'Primary', or 'Run-off' for contests with
   * candidates. For referenda this will be 'Referendum'.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String type;

  /**
   * A number specifying the position of this contest on the voter's ballot.
   * The value returned may be {@code null}.
   */
  public Long getBallotPlacement() {
    return ballotPlacement;
  }

  /**
   * A number specifying the position of this contest on the voter's ballot.
   * The value set may be {@code null}.
   */
  public Contest setBallotPlacement(Long ballotPlacement) {
    this.ballotPlacement = ballotPlacement;
    return this;
  }

  /**
   * The candidate choices for this contest.
   * The value returned may be {@code null}.
   */
  public java.util.List<Candidate> getCandidates() {
    return candidates;
  }

  /**
   * The candidate choices for this contest.
   * The value set may be {@code null}.
   */
  public Contest setCandidates(java.util.List<Candidate> candidates) {
    this.candidates = candidates;
    return this;
  }

  /**
   * Information about the electoral district that this contest is in.
   * The value returned may be {@code null}.
   */
  public ElectoralDistrict getDistrict() {
    return district;
  }

  /**
   * Information about the electoral district that this contest is in.
   * The value set may be {@code null}.
   */
  public Contest setDistrict(ElectoralDistrict district) {
    this.district = district;
    return this;
  }

  /**
   * A description of any additional eligibility requirements for voting in this contest.
   * The value returned may be {@code null}.
   */
  public String getElectorateSpecifications() {
    return electorateSpecifications;
  }

  /**
   * A description of any additional eligibility requirements for voting in this contest.
   * The value set may be {@code null}.
   */
  public Contest setElectorateSpecifications(String electorateSpecifications) {
    this.electorateSpecifications = electorateSpecifications;
    return this;
  }

  /**
   * An ID for this object. IDs may change in future requests and should not be cached. Access to
   * this field requires special access that can be requested from the Request more link on the
   * Quotas page.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * An ID for this object. IDs may change in future requests and should not be cached. Access to
   * this field requires special access that can be requested from the Request more link on the
   * Quotas page.
   * The value set may be {@code null}.
   */
  public Contest setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The level of office for this contest. One of: federal, state, county, city, other
   * The value returned may be {@code null}.
   */
  public String getLevel() {
    return level;
  }

  /**
   * The level of office for this contest. One of: federal, state, county, city, other
   * The value set may be {@code null}.
   */
  public Contest setLevel(String level) {
    this.level = level;
    return this;
  }

  /**
   * The number of candidates that will be elected to office in this contest.
   * The value returned may be {@code null}.
   */
  public Long getNumberElected() {
    return numberElected;
  }

  /**
   * The number of candidates that will be elected to office in this contest.
   * The value set may be {@code null}.
   */
  public Contest setNumberElected(Long numberElected) {
    this.numberElected = numberElected;
    return this;
  }

  /**
   * The number of candidates that a voter may vote for in this contest.
   * The value returned may be {@code null}.
   */
  public Long getNumberVotingFor() {
    return numberVotingFor;
  }

  /**
   * The number of candidates that a voter may vote for in this contest.
   * The value set may be {@code null}.
   */
  public Contest setNumberVotingFor(Long numberVotingFor) {
    this.numberVotingFor = numberVotingFor;
    return this;
  }

  /**
   * The name of the office for this contest.
   * The value returned may be {@code null}.
   */
  public String getOffice() {
    return office;
  }

  /**
   * The name of the office for this contest.
   * The value set may be {@code null}.
   */
  public Contest setOffice(String office) {
    this.office = office;
    return this;
  }

  /**
   * If this is a partisan election, the name of the party it is for.
   * The value returned may be {@code null}.
   */
  public String getPrimaryParty() {
    return primaryParty;
  }

  /**
   * If this is a partisan election, the name of the party it is for.
   * The value set may be {@code null}.
   */
  public Contest setPrimaryParty(String primaryParty) {
    this.primaryParty = primaryParty;
    return this;
  }

  /**
   * A brief description of the referendum. This field is only populated for contests of type
   * 'Referendum'.
   * The value returned may be {@code null}.
   */
  public String getReferendumSubtitle() {
    return referendumSubtitle;
  }

  /**
   * A brief description of the referendum. This field is only populated for contests of type
   * 'Referendum'.
   * The value set may be {@code null}.
   */
  public Contest setReferendumSubtitle(String referendumSubtitle) {
    this.referendumSubtitle = referendumSubtitle;
    return this;
  }

  /**
   * The title of the referendum. (e.g. 'Proposition 42') This field is only populated for contests
   * of type 'Referendum'.
   * The value returned may be {@code null}.
   */
  public String getReferendumTitle() {
    return referendumTitle;
  }

  /**
   * The title of the referendum. (e.g. 'Proposition 42') This field is only populated for contests
   * of type 'Referendum'.
   * The value set may be {@code null}.
   */
  public Contest setReferendumTitle(String referendumTitle) {
    this.referendumTitle = referendumTitle;
    return this;
  }

  /**
   * A link the referendum. This field is only populated for contests of type 'Referendum'.
   * The value returned may be {@code null}.
   */
  public String getReferendumUrl() {
    return referendumUrl;
  }

  /**
   * A link the referendum. This field is only populated for contests of type 'Referendum'.
   * The value set may be {@code null}.
   */
  public Contest setReferendumUrl(String referendumUrl) {
    this.referendumUrl = referendumUrl;
    return this;
  }

  /**
   * A list of sources for this contest. If multiple sources are listed, the data has been
   * aggregated from those sources.
   * The value returned may be {@code null}.
   */
  public java.util.List<Source> getSources() {
    return sources;
  }

  /**
   * A list of sources for this contest. If multiple sources are listed, the data has been
   * aggregated from those sources.
   * The value set may be {@code null}.
   */
  public Contest setSources(java.util.List<Source> sources) {
    this.sources = sources;
    return this;
  }

  /**
   * "Yes" or "No" depending on whether this a contest being held outside the normal election cycle.
   * The value returned may be {@code null}.
   */
  public String getSpecial() {
    return special;
  }

  /**
   * "Yes" or "No" depending on whether this a contest being held outside the normal election cycle.
   * The value set may be {@code null}.
   */
  public Contest setSpecial(String special) {
    this.special = special;
    return this;
  }

  /**
   * The type of contest. Usually this will be 'General', 'Primary', or 'Run-off' for contests with
   * candidates. For referenda this will be 'Referendum'.
   * The value returned may be {@code null}.
   */
  public String getType() {
    return type;
  }

  /**
   * The type of contest. Usually this will be 'General', 'Primary', or 'Run-off' for contests with
   * candidates. For referenda this will be 'Referendum'.
   * The value set may be {@code null}.
   */
  public Contest setType(String type) {
    this.type = type;
    return this;
  }

}
