/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.civicinfo.model;

import com.google.api.client.json.GenericJson;

/**
 * Describes a political geography.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Civic Information API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class GeographicDivision extends GenericJson {

  /**
   * Numerical value between 0 and 1 that expresses level of confidence that a given district is
   * relevant to the request.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Float confidence;

  /**
   * The name of the division.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * The unique Open Civic Data identifier for this division.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String ocdId;

  /**
   * List of offices elected from this division.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Office> offices;

  static {
    // hack to force ProGuard to consider Office used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Office.class);
  }

  /**
   * The type of this division. If unspecified the division's geography is not known.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String type;

  /**
   * Numerical value between 0 and 1 that expresses level of confidence that a given district is
   * relevant to the request.
   * The value returned may be {@code null}.
   */
  public Float getConfidence() {
    return confidence;
  }

  /**
   * Numerical value between 0 and 1 that expresses level of confidence that a given district is
   * relevant to the request.
   * The value set may be {@code null}.
   */
  public GeographicDivision setConfidence(Float confidence) {
    this.confidence = confidence;
    return this;
  }

  /**
   * The name of the division.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * The name of the division.
   * The value set may be {@code null}.
   */
  public GeographicDivision setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * The unique Open Civic Data identifier for this division.
   * The value returned may be {@code null}.
   */
  public String getOcdId() {
    return ocdId;
  }

  /**
   * The unique Open Civic Data identifier for this division.
   * The value set may be {@code null}.
   */
  public GeographicDivision setOcdId(String ocdId) {
    this.ocdId = ocdId;
    return this;
  }

  /**
   * List of offices elected from this division.
   * The value returned may be {@code null}.
   */
  public java.util.List<Office> getOffices() {
    return offices;
  }

  /**
   * List of offices elected from this division.
   * The value set may be {@code null}.
   */
  public GeographicDivision setOffices(java.util.List<Office> offices) {
    this.offices = offices;
    return this;
  }

  /**
   * The type of this division. If unspecified the division's geography is not known.
   * The value returned may be {@code null}.
   */
  public String getType() {
    return type;
  }

  /**
   * The type of this division. If unspecified the division's geography is not known.
   * The value set may be {@code null}.
   */
  public GeographicDivision setType(String type) {
    this.type = type;
    return this;
  }

}
