/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.civicinfo.model;

import com.google.api.client.json.GenericJson;

/**
 * Information about a official holding an elected office.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Civic Information API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Official extends GenericJson {

  /**
   * Addresses at which to contact the official.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<SimpleAddressType> address;

  static {
    // hack to force ProGuard to consider SimpleAddressType used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(SimpleAddressType.class);
  }

  /**
   * A list of known (social) media channels for this official.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Channel> channels;

  static {
    // hack to force ProGuard to consider Channel used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Channel.class);
  }

  /**
   * The direct email addresses for the official.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> emails;

  /**
   * A unique identifier for this official.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The official's name.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * The full name of the party the official belongs to.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String party;

  /**
   * The official's public contact phone numbers.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> phones;

  /**
   * A URL for a photo of the official.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String photoUrl;

  /**
   * The official's public website URLs.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> urls;

  /**
   * Addresses at which to contact the official.
   * The value returned may be {@code null}.
   */
  public java.util.List<SimpleAddressType> getAddress() {
    return address;
  }

  /**
   * Addresses at which to contact the official.
   * The value set may be {@code null}.
   */
  public Official setAddress(java.util.List<SimpleAddressType> address) {
    this.address = address;
    return this;
  }

  /**
   * A list of known (social) media channels for this official.
   * The value returned may be {@code null}.
   */
  public java.util.List<Channel> getChannels() {
    return channels;
  }

  /**
   * A list of known (social) media channels for this official.
   * The value set may be {@code null}.
   */
  public Official setChannels(java.util.List<Channel> channels) {
    this.channels = channels;
    return this;
  }

  /**
   * The direct email addresses for the official.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getEmails() {
    return emails;
  }

  /**
   * The direct email addresses for the official.
   * The value set may be {@code null}.
   */
  public Official setEmails(java.util.List<String> emails) {
    this.emails = emails;
    return this;
  }

  /**
   * A unique identifier for this official.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * A unique identifier for this official.
   * The value set may be {@code null}.
   */
  public Official setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The official's name.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * The official's name.
   * The value set may be {@code null}.
   */
  public Official setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * The full name of the party the official belongs to.
   * The value returned may be {@code null}.
   */
  public String getParty() {
    return party;
  }

  /**
   * The full name of the party the official belongs to.
   * The value set may be {@code null}.
   */
  public Official setParty(String party) {
    this.party = party;
    return this;
  }

  /**
   * The official's public contact phone numbers.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getPhones() {
    return phones;
  }

  /**
   * The official's public contact phone numbers.
   * The value set may be {@code null}.
   */
  public Official setPhones(java.util.List<String> phones) {
    this.phones = phones;
    return this;
  }

  /**
   * A URL for a photo of the official.
   * The value returned may be {@code null}.
   */
  public String getPhotoUrl() {
    return photoUrl;
  }

  /**
   * A URL for a photo of the official.
   * The value set may be {@code null}.
   */
  public Official setPhotoUrl(String photoUrl) {
    this.photoUrl = photoUrl;
    return this;
  }

  /**
   * The official's public website URLs.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getUrls() {
    return urls;
  }

  /**
   * The official's public website URLs.
   * The value set may be {@code null}.
   */
  public Official setUrls(java.util.List<String> urls) {
    this.urls = urls;
    return this;
  }

}
