/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.civicinfo.model;

import com.google.api.client.json.GenericJson;

/**
 * The result of a representative info lookup query.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Civic Information API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class RepresentativeInfoResponse extends GenericJson {

  /**
   * Political geographic divisions that contain the requested address.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<GeographicDivision> divisions;

  static {
    // hack to force ProGuard to consider GeographicDivision used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(GeographicDivision.class);
  }

  /**
   * The kind, fixed to "civicinfo#representativeInfoResponse".
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The normalized version of the requested address
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private SimpleAddressType normalizedInput;

  /**
   * Elected offices referenced by the divisions listed above. Will only be present if "offices" was
   * true in the request.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Office> offices;

  static {
    // hack to force ProGuard to consider Office used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Office.class);
  }

  /**
   * Officials holding the offices listed above. Will only be present if "offices" was true in the
   * request.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Official> officials;

  static {
    // hack to force ProGuard to consider Official used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Official.class);
  }

  /**
   * The result of the request. One of: success, noStreetSegmentFound, addressUnparseable,
   * noAddressParameter, multipleStreetSegmentsFound, electionOver, electionUnknown,
   * internalLookupFailure
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String status;

  /**
   * Political geographic divisions that contain the requested address.
   * The value returned may be {@code null}.
   */
  public java.util.List<GeographicDivision> getDivisions() {
    return divisions;
  }

  /**
   * Political geographic divisions that contain the requested address.
   * The value set may be {@code null}.
   */
  public RepresentativeInfoResponse setDivisions(java.util.List<GeographicDivision> divisions) {
    this.divisions = divisions;
    return this;
  }

  /**
   * The kind, fixed to "civicinfo#representativeInfoResponse".
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind, fixed to "civicinfo#representativeInfoResponse".
   * The value set may be {@code null}.
   */
  public RepresentativeInfoResponse setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The normalized version of the requested address
   * The value returned may be {@code null}.
   */
  public SimpleAddressType getNormalizedInput() {
    return normalizedInput;
  }

  /**
   * The normalized version of the requested address
   * The value set may be {@code null}.
   */
  public RepresentativeInfoResponse setNormalizedInput(SimpleAddressType normalizedInput) {
    this.normalizedInput = normalizedInput;
    return this;
  }

  /**
   * Elected offices referenced by the divisions listed above. Will only be present if "offices" was
   * true in the request.
   * The value returned may be {@code null}.
   */
  public java.util.List<Office> getOffices() {
    return offices;
  }

  /**
   * Elected offices referenced by the divisions listed above. Will only be present if "offices" was
   * true in the request.
   * The value set may be {@code null}.
   */
  public RepresentativeInfoResponse setOffices(java.util.List<Office> offices) {
    this.offices = offices;
    return this;
  }

  /**
   * Officials holding the offices listed above. Will only be present if "offices" was true in the
   * request.
   * The value returned may be {@code null}.
   */
  public java.util.List<Official> getOfficials() {
    return officials;
  }

  /**
   * Officials holding the offices listed above. Will only be present if "offices" was true in the
   * request.
   * The value set may be {@code null}.
   */
  public RepresentativeInfoResponse setOfficials(java.util.List<Official> officials) {
    this.officials = officials;
    return this;
  }

  /**
   * The result of the request. One of: success, noStreetSegmentFound, addressUnparseable,
   * noAddressParameter, multipleStreetSegmentsFound, electionOver, electionUnknown,
   * internalLookupFailure
   * The value returned may be {@code null}.
   */
  public String getStatus() {
    return status;
  }

  /**
   * The result of the request. One of: success, noStreetSegmentFound, addressUnparseable,
   * noAddressParameter, multipleStreetSegmentsFound, electionOver, electionUnknown,
   * internalLookupFailure
   * The value set may be {@code null}.
   */
  public RepresentativeInfoResponse setStatus(String status) {
    this.status = status;
    return this;
  }

}
